@@ -244,6 +244,12 @@ static void document_set_filename(Document *d, gchar *filename,
 	  list_object_notify(document_objects,d);     
 }
 
+void document_forget_filename(Document *d)
+{
+     document_set_filename(d,NULL,FALSE);
+     gtk_signal_emit(GTK_OBJECT(d),document_signals[STATE_CHANGED_SIGNAL]);
+}
+
 Document *document_new_with_chunk(Chunk *chunk, gchar *sourcename,
 				  StatusBar *bar)
 {
@@ -717,7 +723,7 @@ void document_zoom(Document *d, gfloat zoom, gboolean followcursor)
 	printf("d->cursorpos: %d, d->viewstart: %d, d->viewend: %d\n",
 	(int)d->cursorpos,(int)d->viewstart,(int)d->viewend); */
      if (followcursor && d->cursorpos >= d->viewstart && 
-	 d->cursorpos < d->viewend)
+	 d->cursorpos <= d->viewend)
 	  newstart = d->cursorpos - newdist/2;
      else
 	  newstart = d->viewstart + (dist - newdist)/2;
@@ -865,3 +871,8 @@ gboolean document_update_cursors(void)
 
      return TRUE;
 }
+
+void document_set_status_bar(Document *d, StatusBar *bar)
+{
+     d->bar = bar;
+}
