@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002 2003 2004 2005, Magnus Hjorth
+ * Copyright (C) 2002 2003 2004 2005 2006, Magnus Hjorth
  *
  * This file is part of mhWaveEdit.
  *
@@ -300,6 +300,7 @@ static void cleanup_filename(gchar *fn)
 static gchar *get_filename_result;
 static gboolean get_filename_quitflag;
 static gboolean get_filename_savemode;
+static GtkFileSelection *get_filename_fs;
 
 static void get_filename_callback(GtkButton *button, gpointer user_data)
 {
@@ -335,8 +336,18 @@ static void get_filename_destroy(void)
      get_filename_quitflag = TRUE;
 }
 
+static gchar *get_filename_internal_get_name(void)
+{
+     return g_strdup(gtk_file_selection_get_filename(get_filename_fs));
+}
+
+static void get_filename_internal_set_name(gchar *new_name)
+{
+     gtk_file_selection_set_filename(get_filename_fs,new_name);
+}
+
 gchar *get_filename(gchar *current_name, gchar *filemask, gchar *title_text,
-		    gboolean savemode)
+		    gboolean savemode, GtkWidget *custom_widget)
 {
      GtkFileSelection *f;
      GtkAllocation all;
@@ -345,6 +356,10 @@ gchar *get_filename(gchar *current_name, gchar *filemask, gchar *title_text,
      get_filename_result=NULL;
      get_filename_savemode = savemode;
      f=GTK_FILE_SELECTION(gtk_file_selection_new(title_text));
+     get_filename_fs = f;
+     if (custom_widget != NULL)
+	  gtk_box_pack_end(GTK_BOX(GTK_FILE_SELECTION(f)->main_vbox),
+			   custom_widget, FALSE, FALSE, 0);
      c = inifile_get("fileGeometry",NULL);     
      if (c!=NULL && inifile_get_gboolean("useGeometry",FALSE) &&
 	 !parse_geom(c,&all)) {
@@ -439,6 +454,8 @@ gchar *get_directory(gchar *current_name, gchar *title_text)
 
 /* Use the GtkFileChooserDialog */
 
+static GtkFileChooser *get_filename_fc;
+
 struct response {
      gboolean savemode;
      gboolean responded;
@@ -461,10 +478,29 @@ static void response(GtkDialog *dialog, gint arg1, gpointer user_data)
      sr->r = arg1;
 }
 
+static gchar *get_filename_internal_get_name(void)
+{
+     gchar *c;
+     c = gtk_file_chooser_get_filename(get_filename_fc);
+     if (c == NULL) return g_strdup("");
+     return c;
+}
+
+static void get_filename_internal_set_name(gchar *new_name)
+{
+     gchar *c,*d;
+     c = g_filename_to_utf8(new_name,-1,NULL,NULL,NULL);
+     gtk_file_chooser_set_filename(get_filename_fc,c);
+     d = strrchr(c,'/');
+     if (d != NULL && d[1] != 0)
+	  gtk_file_chooser_set_current_name(get_filename_fc,d+1);
+     g_free(c);
+}
+
 static gchar *get_filename_main(gchar *current_name, gchar *title_text, 
 				gboolean savemode, 
 				GtkFileChooserAction action, 
-				gchar *geom_setting)
+				gchar *geom_setting, GtkWidget *custom_widget)
 {
      GtkWidget *w;
      GtkFileChooser *fc;
@@ -480,6 +516,10 @@ static gchar *get_filename_main(gchar *current_name, gchar *title_text,
 				     savemode?GTK_STOCK_SAVE_AS:GTK_STOCK_OPEN,
 				     GTK_RESPONSE_ACCEPT,GTK_STOCK_CANCEL,
 				     GTK_RESPONSE_CANCEL,NULL);
+     fc = GTK_FILE_CHOOSER(w);
+     get_filename_fc = fc;
+     if (custom_widget != NULL)
+	  gtk_file_chooser_set_extra_widget(fc, custom_widget);
      
      d = inifile_get(geom_setting,NULL);
      if (d!=NULL && !savemode && inifile_get_gboolean("useGeometry",FALSE) &&
@@ -490,7 +530,6 @@ static gchar *get_filename_main(gchar *current_name, gchar *title_text,
 	  gtk_window_set_position(GTK_WINDOW(w),GTK_WIN_POS_CENTER);
      gtk_window_set_modal(GTK_WINDOW(w),TRUE);
 
-     fc = GTK_FILE_CHOOSER(w);
      if (c != NULL) {
 	  if (c[0] == '/' &&
 	      (action == GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER || 
@@ -526,22 +565,40 @@ static gchar *get_filename_main(gchar *current_name, gchar *title_text,
 }
 
 gchar *get_filename(gchar *current_name, gchar *filemask, gchar *title_text,
-		    gboolean savemode)
+		    gboolean savemode, GtkWidget *custom_widget)
 {
      return get_filename_main(current_name,title_text,savemode,
 			      savemode?GTK_FILE_CHOOSER_ACTION_SAVE:
-			      GTK_FILE_CHOOSER_ACTION_OPEN,"fileGeometry");
+			      GTK_FILE_CHOOSER_ACTION_OPEN,"fileGeometry",
+			      custom_widget);
 }
 
 gchar *get_directory(gchar *current_name, gchar *title_text)
 {
      return get_filename_main(current_name,title_text,FALSE,
 			      GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
-			      "dirGeometry");
+			      "dirGeometry",NULL);
 }
 
 #endif
 
+void get_filename_modify_extension(gchar *new_extension)
+{
+     gchar *c,*d,*e,*f;
+     c = get_filename_internal_get_name();
+     d = strrchr(c,'.');
+     e = strrchr(c,'/');
+     if (d != NULL && (e == NULL || e < d))
+	  *d = 0;
+     if (c[0] != 0 && (e == NULL || e[1] != 0)) {
+	  printf("%s\n",c);
+	  f = g_strdup_printf("%s%s",c,new_extension);
+	  get_filename_internal_set_name(f);
+	  g_free(f);
+     }
+     g_free(c);
+}
+
 gboolean e_copydata(EFILE *from, EFILE *to, off_t bytes)
 {
      off_t count;
